@@ -54,10 +54,10 @@ create_build_from_storage_body = {
     "steps": [
         {
             "name": "gcr.io/cloud-builders/docker",
-            "args": ["build", "-t", "gcr.io/$PROJECT_ID/{}".format(GCP_SOURCE_BUCKET_NAME), "."],
+            "args": ["build", "-t", f"gcr.io/$PROJECT_ID/{GCP_SOURCE_BUCKET_NAME}", "."],
         }
     ],
-    "images": ["gcr.io/$PROJECT_ID/{}".format(GCP_SOURCE_BUCKET_NAME)],
+    "images": [f"gcr.io/$PROJECT_ID/{GCP_SOURCE_BUCKET_NAME}"],
 }
 # [END howto_operator_gcp_create_build_from_storage_body]
 
@@ -103,9 +103,10 @@ with models.DAG(
 
     # [START howto_operator_gcp_create_build_from_yaml_body]
     create_build_from_file = CloudBuildCreateBuildOperator(
-        task_id="create_build_from_file", project_id=GCP_PROJECT_ID,
+        task_id="create_build_from_file",
+        project_id=GCP_PROJECT_ID,
         body=str(CURRENT_FOLDER.joinpath('example_cloud_build.yaml')),
-        params={'name': 'Airflow'}
+        params={'name': 'Airflow'},
     )
     # [END howto_operator_gcp_create_build_from_yaml_body]
     create_build_from_storage >> create_build_from_storage_result  # pylint: disable=pointless-statement
