@@ -18,11 +18,14 @@
 """
 Example DAG using PostgresToGoogleCloudStorageOperator.
 """
+import os
+
 from airflow import models
 from airflow.providers.google.cloud.transfers.postgres_to_gcs import PostgresToGCSOperator
 from airflow.utils.dates import days_ago
 
-GCS_BUCKET = "postgres_to_gcs_example"
+PROJECT_ID = os.environ.get("GCP_PROJECT_ID", "example-project")
+GCS_BUCKET = os.environ.get("GCP_GCS_BUCKET_NAME", "postgres_to_gcs_example")
 FILENAME = "test_file"
 SQL_QUERY = "select * from test_table;"
 
@@ -34,3 +37,12 @@ with models.DAG(
     upload_data = PostgresToGCSOperator(
         task_id="get_data", sql=SQL_QUERY, bucket=GCS_BUCKET, filename=FILENAME, gzip=False
     )
+
+    upload_data_server_side_cursor = PostgresToGCSOperator(
+        task_id="get_data_with_server_side_cursor",
+        sql=SQL_QUERY,
+        bucket=GCS_BUCKET,
+        filename=FILENAME,
+        gzip=False,
+        use_server_side_cursor=True,
+    )
