@@ -25,11 +25,9 @@ from airflow.utils.dates import days_ago
 BUCKET = os.environ.get("GCP_GCS_BUCKET", "test28397yeo")
 SPREADSHEET_ID = os.environ.get("SPREADSHEET_ID", "1234567890qwerty")
 
-default_args = {"start_date": days_ago(1)}
-
 with models.DAG(
     "example_sheets_to_gcs",
-    default_args=default_args,
+    start_date=days_ago(1),
     schedule_interval=None,
 ) as dag:
     # [START upload_sheet_to_gcs]
