@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains a Google Pub/Sub Hook.
-"""
+"""This module contains a Google Pub/Sub Hook."""
 import warnings
 from base64 import b64decode
 from typing import Dict, List, Optional, Sequence, Tuple, Union
@@ -44,9 +42,7 @@ from airflow.version import version
 
 
 class PubSubException(Exception):
-    """
-    Alias for Exception.
-    """
+    """Alias for Exception."""
 
 
 class PubSubHook(GoogleBaseHook):
@@ -95,7 +91,7 @@ class PubSubHook(GoogleBaseHook):
     def publish(
         self,
         topic: str,
-        messages: List[Dict],
+        messages: List[dict],
         project_id: str,
     ) -> None:
         """
@@ -115,7 +111,7 @@ class PubSubHook(GoogleBaseHook):
         self._validate_messages(messages)
 
         publisher = self.get_conn()
-        topic_path = PublisherClient.topic_path(project_id, topic)  # pylint: disable=no-member
+        topic_path = f"projects/{project_id}/topics/{topic}"
 
         self.log.info("Publish %d messages to topic (path) %s", len(messages), topic_path)
         try:
@@ -210,7 +206,7 @@ class PubSubHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]]
         """
         publisher = self.get_conn()
-        topic_path = PublisherClient.topic_path(project_id, topic)  # pylint: disable=no-member
+        topic_path = f"projects/{project_id}/topics/{topic}"
 
         # Add airflow-version label to the topic
         labels = labels or {}
@@ -220,20 +216,22 @@ class PubSubHook(GoogleBaseHook):
         try:
             # pylint: disable=no-member
             publisher.create_topic(
-                name=topic_path,
-                labels=labels,
-                message_storage_policy=message_storage_policy,
-                kms_key_name=kms_key_name,
+                request={
+                    "name": topic_path,
+                    "labels": labels,
+                    "message_storage_policy": message_storage_policy,
+                    "kms_key_name": kms_key_name,
+                },
                 retry=retry,
                 timeout=timeout,
-                metadata=metadata,
+                metadata=metadata or (),
             )
         except AlreadyExists:
             self.log.warning('Topic already exists: %s', topic)
             if fail_if_exists:
-                raise PubSubException('Topic already exists: {}'.format(topic))
+                raise PubSubException(f'Topic already exists: {topic}')
         except GoogleAPICallError as e:
-            raise PubSubException('Error creating topic {}'.format(topic), e)
+            raise PubSubException(f'Error creating topic {topic}', e)
 
         self.log.info("Created topic (path) %s", topic_path)
 
@@ -270,23 +268,20 @@ class PubSubHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]]
         """
         publisher = self.get_conn()
-        topic_path = PublisherClient.topic_path(project_id, topic)  # pylint: disable=no-member
+        topic_path = f"projects/{project_id}/topics/{topic}"
 
         self.log.info("Deleting topic (path) %s", topic_path)
         try:
             # pylint: disable=no-member
             publisher.delete_topic(
-                topic=topic_path,
-                retry=retry,
-                timeout=timeout,
-                metadata=metadata,
+                request={"topic": topic_path}, retry=retry, timeout=timeout, metadata=metadata or ()
             )
         except NotFound:
             self.log.warning('Topic does not exist: %s', topic_path)
             if fail_if_not_exists:
-                raise PubSubException('Topic does not exist: {}'.format(topic_path))
+                raise PubSubException(f'Topic does not exist: {topic_path}')
         except GoogleAPICallError as e:
-            raise PubSubException('Error deleting topic {}'.format(topic), e)
+            raise PubSubException(f'Error deleting topic {topic}', e)
         self.log.info("Deleted topic (path) %s", topic_path)
 
     # pylint: disable=too-many-arguments
@@ -299,15 +294,15 @@ class PubSubHook(GoogleBaseHook):
         subscription_project_id: Optional[str] = None,
         ack_deadline_secs: int = 10,
         fail_if_exists: bool = False,
-        push_config: Optional[Union[Dict, PushConfig]] = None,
+        push_config: Optional[Union[dict, PushConfig]] = None,
         retain_acked_messages: Optional[bool] = None,
-        message_retention_duration: Optional[Union[Dict, Duration]] = None,
+        message_retention_duration: Optional[Union[dict, Duration]] = None,
         labels: Optional[Dict[str, str]] = None,
         enable_message_ordering: bool = False,
-        expiration_policy: Optional[Union[Dict, ExpirationPolicy]] = None,
+        expiration_policy: Optional[Union[dict, ExpirationPolicy]] = None,
         filter_: Optional[str] = None,
-        dead_letter_policy: Optional[Union[Dict, DeadLetterPolicy]] = None,
-        retry_policy: Optional[Union[Dict, RetryPolicy]] = None,
+        dead_letter_policy: Optional[Union[dict, DeadLetterPolicy]] = None,
+        retry_policy: Optional[Union[dict, RetryPolicy]] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
@@ -396,7 +391,7 @@ class PubSubHook(GoogleBaseHook):
         subscriber = self.subscriber_client
 
         if not subscription:
-            subscription = 'sub-{}'.format(uuid4())
+            subscription = f'sub-{uuid4()}'
         if not subscription_project_id:
             subscription_project_id = project_id
 
@@ -405,34 +400,36 @@ class PubSubHook(GoogleBaseHook):
         labels['airflow-version'] = 'v' + version.replace('.', '-').replace('+', '-')
 
         # pylint: disable=no-member
-        subscription_path = SubscriberClient.subscription_path(subscription_project_id, subscription)
-        topic_path = SubscriberClient.topic_path(project_id, topic)
+        subscription_path = f"projects/{subscription_project_id}/subscriptions/{subscription}"
+        topic_path = f"projects/{project_id}/topics/{topic}"
 
         self.log.info("Creating subscription (path) %s for topic (path) %a", subscription_path, topic_path)
         try:
             subscriber.create_subscription(
-                name=subscription_path,
-                topic=topic_path,
-                push_config=push_config,
-                ack_deadline_seconds=ack_deadline_secs,
-                retain_acked_messages=retain_acked_messages,
-                message_retention_duration=message_retention_duration,
-                labels=labels,
-                enable_message_ordering=enable_message_ordering,
-                expiration_policy=expiration_policy,
-                filter_=filter_,
-                dead_letter_policy=dead_letter_policy,
-                retry_policy=retry_policy,
+                request={
+                    "name": subscription_path,
+                    "topic": topic_path,
+                    "push_config": push_config,
+                    "ack_deadline_seconds": ack_deadline_secs,
+                    "retain_acked_messages": retain_acked_messages,
+                    "message_retention_duration": message_retention_duration,
+                    "labels": labels,
+                    "enable_message_ordering": enable_message_ordering,
+                    "expiration_policy": expiration_policy,
+                    "filter": filter_,
+                    "dead_letter_policy": dead_letter_policy,
+                    "retry_policy": retry_policy,
+                },
                 retry=retry,
                 timeout=timeout,
-                metadata=metadata,
+                metadata=metadata or (),
             )
         except AlreadyExists:
             self.log.warning('Subscription already exists: %s', subscription_path)
             if fail_if_exists:
-                raise PubSubException('Subscription already exists: {}'.format(subscription_path))
+                raise PubSubException(f'Subscription already exists: {subscription_path}')
         except GoogleAPICallError as e:
-            raise PubSubException('Error creating subscription {}'.format(subscription_path), e)
+            raise PubSubException(f'Error creating subscription {subscription_path}', e)
 
         self.log.info("Created subscription (path) %s for topic (path) %s", subscription_path, topic_path)
         return subscription
@@ -470,21 +467,24 @@ class PubSubHook(GoogleBaseHook):
         """
         subscriber = self.subscriber_client
         # noqa E501 # pylint: disable=no-member
-        subscription_path = SubscriberClient.subscription_path(project_id, subscription)
+        subscription_path = f"projects/{project_id}/subscriptions/{subscription}"
 
         self.log.info("Deleting subscription (path) %s", subscription_path)
         try:
             # pylint: disable=no-member
             subscriber.delete_subscription(
-                subscription=subscription_path, retry=retry, timeout=timeout, metadata=metadata
+                request={"subscription": subscription_path},
+                retry=retry,
+                timeout=timeout,
+                metadata=metadata or (),
             )
 
         except NotFound:
             self.log.warning('Subscription does not exist: %s', subscription_path)
             if fail_if_not_exists:
-                raise PubSubException('Subscription does not exist: {}'.format(subscription_path))
+                raise PubSubException(f'Subscription does not exist: {subscription_path}')
         except GoogleAPICallError as e:
-            raise PubSubException('Error deleting subscription {}'.format(subscription_path), e)
+            raise PubSubException(f'Error deleting subscription {subscription_path}', e)
 
         self.log.info("Deleted subscription (path) %s", subscription_path)
 
@@ -531,24 +531,26 @@ class PubSubHook(GoogleBaseHook):
         """
         subscriber = self.subscriber_client
         # noqa E501 # pylint: disable=no-member,line-too-long
-        subscription_path = SubscriberClient.subscription_path(project_id, subscription)
+        subscription_path = f"projects/{project_id}/subscriptions/{subscription}"
 
         self.log.info("Pulling max %d messages from subscription (path) %s", max_messages, subscription_path)
         try:
             # pylint: disable=no-member
             response = subscriber.pull(
-                subscription=subscription_path,
-                max_messages=max_messages,
-                return_immediately=return_immediately,
+                request={
+                    "subscription": subscription_path,
+                    "max_messages": max_messages,
+                    "return_immediately": return_immediately,
+                },
                 retry=retry,
                 timeout=timeout,
-                metadata=metadata,
+                metadata=metadata or (),
             )
             result = getattr(response, 'received_messages', [])
             self.log.info("Pulled %d messages from subscription (path) %s", len(result), subscription_path)
             return result
         except (HttpError, GoogleAPICallError) as e:
-            raise PubSubException('Error pulling messages from subscription {}'.format(subscription_path), e)
+            raise PubSubException(f'Error pulling messages from subscription {subscription_path}', e)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def acknowledge(
@@ -595,17 +597,16 @@ class PubSubHook(GoogleBaseHook):
 
         subscriber = self.subscriber_client
         # noqa E501 # pylint: disable=no-member
-        subscription_path = SubscriberClient.subscription_path(project_id, subscription)
+        subscription_path = f"projects/{project_id}/subscriptions/{subscription}"
 
         self.log.info("Acknowledging %d ack_ids from subscription (path) %s", len(ack_ids), subscription_path)
         try:
             # pylint: disable=no-member
             subscriber.acknowledge(
-                subscription=subscription_path,
-                ack_ids=ack_ids,
+                request={"subscription": subscription_path, "ack_ids": ack_ids},
                 retry=retry,
                 timeout=timeout,
-                metadata=metadata,
+                metadata=metadata or (),
             )
         except (HttpError, GoogleAPICallError) as e:
             raise PubSubException(
