@@ -20,9 +20,8 @@ from typing import Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core.retry import Retry
 from google.cloud.memcache_v1beta2.types import cloud_memcache
-from google.cloud.redis_v1.gapic.enums import FailoverInstanceRequest
-from google.cloud.redis_v1.types import FieldMask, InputConfig, Instance, OutputConfig
-from google.protobuf.json_format import MessageToDict
+from google.cloud.redis_v1 import FailoverInstanceRequest, InputConfig, Instance, OutputConfig
+from google.protobuf.field_mask_pb2 import FieldMask
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.cloud_memorystore import (
@@ -134,7 +133,7 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
-        return MessageToDict(result)
+        return Instance.to_dict(result)
 
 
 class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
@@ -492,7 +491,7 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
-        return MessageToDict(result)
+        return Instance.to_dict(result)
 
 
 class CloudMemorystoreImportOperator(BaseOperator):
@@ -677,7 +676,7 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
-        instances = [MessageToDict(a) for a in result]
+        instances = [Instance.to_dict(a) for a in result]
         return instances
 
 
@@ -1290,7 +1289,7 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
-        return hook.proto_message_to_dict(result)
+        return cloud_memcache.Instance.to_dict(result)
 
 
 class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
@@ -1438,7 +1437,7 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
-        return hook.proto_message_to_dict(result)
+        return cloud_memcache.Instance.to_dict(result)
 
 
 class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
@@ -1520,7 +1519,7 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
-        instances = [hook.proto_message_to_dict(a) for a in result]
+        instances = [cloud_memcache.Instance.to_dict(a) for a in result]
         return instances
 
 
