@@ -198,9 +198,7 @@ class CloudFunctionDeployFunctionOperator(BaseOperator):
     def _check_if_function_exists(self, hook) -> bool:
         name = self.body.get('name')
         if not name:
-            raise GcpFieldValidationException(
-                "The 'name' field should be present in " "body: '{}'.".format(self.body)
-            )
+            raise GcpFieldValidationException(f"The 'name' field should be present in body: '{self.body}'.")
         try:
             hook.get_function(name)
         except HttpError as e:
@@ -385,7 +383,7 @@ class CloudFunctionDeleteFunctionOperator(BaseOperator):
         else:
             pattern = FUNCTION_NAME_COMPILED_PATTERN
             if not pattern.match(self.name):
-                raise AttributeError('Parameter name must match pattern: {}'.format(FUNCTION_NAME_PATTERN))
+                raise AttributeError(f'Parameter name must match pattern: {FUNCTION_NAME_PATTERN}')
 
     def execute(self, context):
         hook = CloudFunctionsHook(
@@ -399,6 +397,7 @@ class CloudFunctionDeleteFunctionOperator(BaseOperator):
             status = e.resp.status
             if status == 404:
                 self.log.info('The function does not exist in this project')
+                return None
             else:
                 self.log.error('An error occurred. Exiting.')
                 raise e
