@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains a Google Cloud Storage operator.
-"""
+"""This module contains a Google Cloud Storage operator."""
 import warnings
 from typing import Optional, Sequence, Union
 
@@ -236,7 +234,7 @@ class GCSToGCSOperator(BaseOperator):
     def execute(self, context):
 
         hook = GCSHook(
-            google_cloud_storage_conn_id=self.gcp_conn_id,
+            gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
@@ -282,6 +280,47 @@ class GCSToGCSOperator(BaseOperator):
                 self._copy_source_without_wildcard(hook=hook, prefix=prefix)
 
     def _copy_source_without_wildcard(self, hook, prefix):
+        """
+
+
+        For source_objects with no wildcard, this operator would first list
+        all files in source_objects, using provided delimiter if any. Then copy
+        files from source_objects to destination_object and rename each source
+        file.
+
+        Example 1:
+
+
+        The following Operator would copy all the files from ``a/``folder
+        (i.e a/a.csv, a/b.csv, a/c.csv)in ``data`` bucket to the ``b/`` folder in
+        the ``data_backup`` bucket (b/a.csv, b/b.csv, b/c.csv) ::
+
+            copy_files = GCSToGCSOperator(
+                task_id='copy_files_without_wildcard',
+                source_bucket='data',
+                source_objects=['a/'],
+                destination_bucket='data_backup',
+                destination_object='b/',
+                gcp_conn_id=google_cloud_conn_id
+            )
+
+        Example 2:
+
+
+        The following Operator would copy all avro files from ``a/``folder
+        (i.e a/a.avro, a/b.avro, a/c.avro)in ``data`` bucket to the ``b/`` folder in
+        the ``data_backup`` bucket (b/a.avro, b/b.avro, b/c.avro) ::
+
+            copy_files = GCSToGCSOperator(
+                task_id='copy_files_without_wildcard',
+                source_bucket='data',
+                source_objects=['a/'],
+                destination_bucket='data_backup',
+                destination_object='b/',
+                delimiter='.avro',
+                gcp_conn_id=google_cloud_conn_id
+            )
+        """
         objects = hook.list(self.source_bucket, prefix=prefix, delimiter=self.delimiter)
 
         # If objects is empty and we have prefix, let's check if prefix is a blob
@@ -295,7 +334,7 @@ class GCSToGCSOperator(BaseOperator):
             if self.destination_object is None:
                 destination_object = source_obj
             else:
-                destination_object = self.destination_object
+                destination_object = source_obj.replace(prefix, self.destination_object, 1)
             self._copy_single_object(
                 hook=hook, source_object=source_obj, destination_object=destination_object
             )
