@@ -21,7 +21,7 @@ You can execute this module to get ID Token.
 
 To obtain info about this token, run the following commands:
 
-    ID_TOKEN="$(python -m airflow.providers.google.common.utils.id_token_credentials_provider)"
+    ID_TOKEN="$(python -m airflow.providers.google.common.utils.id_token_credentials)"
     curl "https://www.googleapis.com/oauth2/v3/tokeninfo?id_token=${ID_TOKEN}" -v
 """
 
@@ -30,9 +30,10 @@ import os
 from typing import Optional
 
 import google.auth.transport
+import google.oauth2
 from google.auth import credentials as google_auth_credentials, environment_vars, exceptions
 from google.auth._default import _AUTHORIZED_USER_TYPE, _HELP_MESSAGE, _SERVICE_ACCOUNT_TYPE, _VALID_TYPES
-from google.oauth2 import credentials as oauth2_credentials
+from google.oauth2 import credentials as oauth2_credentials, service_account
 
 
 class IDTokenCredentialsAdapter(google_auth_credentials.Credentials):
@@ -88,8 +89,6 @@ def _load_credentials_from_file(
         return current_credentials
 
     elif credential_type == _SERVICE_ACCOUNT_TYPE:
-        from google.oauth2 import service_account
-
         try:
             return service_account.IDTokenCredentials.from_service_account_info(
                 info, target_audience=target_audience
@@ -206,8 +205,8 @@ def get_default_id_token_credentials(
 if __name__ == "__main__":
     from google.auth.transport import requests
 
-    request_adaapter = requests.Request()
+    request_adapter = requests.Request()
 
     creds = get_default_id_token_credentials(target_audience=None)
-    creds.refresh(request=request_adaapter)
+    creds.refresh(request=request_adapter)
     print(creds.token)
